==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/de_DE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Der angegebene Operator ist falsch",
    "The given regular expression is invalid" : "Der angegebene reguläre Ausdruck ist falsch",
    "The given file size is invalid" : "Die angegebene Dateigröße ist ungültig",
    "The given tag id is invalid" : "Die angegebene Schlagwort-ID ist ungültig",
    "The given IP range is invalid" : "Der angegebene IP-Bereich ist falsch",
    "The given IP range is not valid for IPv4" : "Der angegebene IP-Bereich ist für IPv4 ungültig",
    "The given IP range is not valid for IPv6" : "Der angegebene IP-Bereich ist für IPv6 ungültig",
    "The given time span is invalid" : "Die angegebene Zeitspanne ist ungültig",
    "The given start time is invalid" : "Die angegebene Startzeit ist ungültig",
    "The given end time is invalid" : "Die angegebene Endzeit ist ungültig",
    "The given group does not exist" : "Die angegebene Gruppe existiert nicht",
    "File" : "Datei",
    "File created" : "Datei erstellt",
    "File updated" : "Datei aktualisiert",
    "File renamed" : "Datei umbenannt",
    "File deleted" : "Datei gelöscht",
    "File accessed" : "Auf Datei zugegriffen",
    "File copied" : "Datei kopiert",
    "Tag assigned" : "Schlagwort zugewiesen",
    "Someone" : "Irgendjemand",
    "%s created %s" : "%s hat %s erstellt",
    "%s modified %s" : "%shat %s geändert",
    "%s deleted %s" : "%s hat  %s gelöscht",
    "%s accessed %s" : "%s hat auf %s zugegriffen",
    "%s renamed %s" : "%shat %s umbenannt",
    "%s copied %s" : "%s hat %s kopiert",
    "%s assigned %s to %s" : "%s hat %s zugewiesen an %s",
    "Operation #%s does not exist" : "Operation #%s existiert nicht",
    "Entity %s does not exist" : "Entität %s existiert nicht",
    "Entity %s is invalid" : "Entität %s ist ungültig",
    "No events are chosen." : "Keine Ereignisse ausgewählt.",
    "Entity %s has no event %s" : "Die Entität %s hat kein Ereignis %s",
    "Operation %s does not exist" : "Operation %s existiert nicht",
    "Operation %s is invalid" : "Operation %s ist ungültig",
    "At least one check needs to be provided" : "Mindestens ein Test muss bereitgestellt werden",
    "The provided operation data is too long" : "Die bereitgestellten Betriebsdaten sind zu lang",
    "Invalid check provided" : "Ungültiger Test bereitgestellt",
    "Check %s does not exist" : "Die Prüfung %s existiert nicht",
    "Check %s is invalid" : "Die Prüfung %s ist ungültig",
    "Check %s is not allowed with this entity" : "Die Prüfung %s ist mit dieser Entität unzulässig",
    "The provided check value is too long" : "Der bereitgestellte Prüfwert ist zu lang",
    "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
    "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
    "Flow" : "Ablauf",
    "Nextcloud workflow engine" : "Nextcloud Arbeitsablauf-Engine",
    "Select a filter" : "Filter wählen",
    "Select a comparator" : "Wählen Sie einen Komparator",
    "Remove filter" : "Filter entfernen",
    "Audio" : "Audio",
    "Folder" : "Ordner",
    "Images" : "Bilder",
    "Office documents" : "Office-Dokumente",
    "PDF documents" : "PDF-Dokumente",
    "Video" : "Video",
    "Custom MIME type" : "Benutzerdefinierter MIME Typ",
    "Custom mimetype" : "Benutzerdefinierter MIME-Typ",
    "Select a file type" : "Dateityp auswählen",
    "e.g. httpd/unix-directory" : "z.B. httpd/unix-directory",
    "Please enter a valid time span" : "Bitte einen gültigen Zeitraum angeben",
    "Files WebDAV" : "WebDAV für Dateien",
    "Custom URL" : "Benutzerdefinierte URL",
    "Select a request URL" : "Wählen Sie eine Anforderungs-URL aus",
    "Android client" : "Android-Client",
    "iOS client" : "iOS-Client",
    "Desktop client" : "Desktop-Client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook Addons",
    "Custom user agent" : "Benutzerdefinierter User-Agent",
    "Select a user agent" : "User-Agenten wählen",
    "Select groups" : "Gruppen auswählen",
    "Groups" : "Gruppen",
    "Type to search for group …" : "Tippen um nach einer Gruppe zu suchen …",
    "Select a trigger" : "Einen Auslöser auswählen",
    "At least one event must be selected" : "Mindestens ein Termin muss ausgewählt werden",
    "Add new flow" : "Neuen Ablauf hinzufügen",
    "The configuration is invalid" : "Die Konfiguration ist ungültig",
    "Active" : "Aktiv",
    "Save" : "Speichern",
    "When" : "Wenn",
    "and" : "und",
    "Add a new filter" : "Neuen Filter hinzufügen",
    "Cancel" : "Abbrechen",
    "Delete" : "Löschen",
    "Available flows" : "Verfügbare Abläufe",
    "For details on how to write your own flow, check out the development documentation." : "Informationen wie eigene Abläufe erstellt werden, finden Sie in der Entwickler-Dokumentation.",
    "No flows installed" : "Keine Abläufe installiert",
    "Ask your administrator to install new flows." : "Bitten Sie Ihre Administration, neue Abläufe zu installieren.",
    "More flows" : "Weitere Abläufe",
    "Browse the App Store" : "App-Store durchsuchen",
    "Show less" : "Weniger anzeigen",
    "Show more" : "Mehr anzeigen",
    "Configured flows" : "Konfigurierte Abläufe",
    "Your flows" : "Ihre Abläufe",
    "No flows configured" : "Keine Abläufe eingerichtet",
    "matches" : "entspricht",
    "does not match" : "entspricht nicht",
    "is" : "ist",
    "is not" : "ist nicht",
    "File name" : "Dateiname",
    "File MIME type" : "Datei MIME-Typ",
    "File size (upload)" : "Dateigröße (beim Hochladen)",
    "less" : "weniger",
    "less or equals" : "weniger oder gleich",
    "greater or equals" : "größer oder gleich",
    "greater" : "größer",
    "Request remote address" : "Entfernte Adresse der Anfrage",
    "matches IPv4" : "entspricht IPv4",
    "does not match IPv4" : "entspricht nicht IPv4",
    "matches IPv6" : "entspricht IPv6",
    "does not match IPv6" : "entspricht nicht IPv6",
    "File system tag" : "Kollaboratives Schlagwort an Datei",
    "is tagged with" : "ist getaggt mit",
    "is not tagged with" : "ist nicht getaggt mit",
    "Request URL" : "Anfrage-URL",
    "Request time" : "Anfrage-Zeitpunkt",
    "between" : "zwischen",
    "not between" : "nicht zwischen",
    "Request user agent" : "User-Agent anfragen",
    "Group membership" : "Gruppenmitgliedschaft",
    "is member of" : "Ist Mitglied von",
    "is not member of" : "Ist kein Mitglied von"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/de_DE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Der angegebene Operator ist falsch",
    "The given regular expression is invalid" : "Der angegebene reguläre Ausdruck ist falsch",
    "The given file size is invalid" : "Die angegebene Dateigröße ist ungültig",
    "The given tag id is invalid" : "Die angegebene Schlagwort-ID ist ungültig",
    "The given IP range is invalid" : "Der angegebene IP-Bereich ist falsch",
    "The given IP range is not valid for IPv4" : "Der angegebene IP-Bereich ist für IPv4 ungültig",
    "The given IP range is not valid for IPv6" : "Der angegebene IP-Bereich ist für IPv6 ungültig",
    "The given time span is invalid" : "Die angegebene Zeitspanne ist ungültig",
    "The given start time is invalid" : "Die angegebene Startzeit ist ungültig",
    "The given end time is invalid" : "Die angegebene Endzeit ist ungültig",
    "The given group does not exist" : "Die angegebene Gruppe existiert nicht",
    "File" : "Datei",
    "File created" : "Datei erstellt",
    "File updated" : "Datei aktualisiert",
    "File renamed" : "Datei umbenannt",
    "File deleted" : "Datei gelöscht",
    "File accessed" : "Auf Datei zugegriffen",
    "File copied" : "Datei kopiert",
    "Tag assigned" : "Schlagwort zugewiesen",
    "Someone" : "Irgendjemand",
    "%s created %s" : "%s hat %s erstellt",
    "%s modified %s" : "%shat %s geändert",
    "%s deleted %s" : "%s hat  %s gelöscht",
    "%s accessed %s" : "%s hat auf %s zugegriffen",
    "%s renamed %s" : "%shat %s umbenannt",
    "%s copied %s" : "%s hat %s kopiert",
    "%s assigned %s to %s" : "%s hat %s zugewiesen an %s",
    "Operation #%s does not exist" : "Operation #%s existiert nicht",
    "Entity %s does not exist" : "Entität %s existiert nicht",
    "Entity %s is invalid" : "Entität %s ist ungültig",
    "No events are chosen." : "Keine Ereignisse ausgewählt.",
    "Entity %s has no event %s" : "Die Entität %s hat kein Ereignis %s",
    "Operation %s does not exist" : "Operation %s existiert nicht",
    "Operation %s is invalid" : "Operation %s ist ungültig",
    "At least one check needs to be provided" : "Mindestens ein Test muss bereitgestellt werden",
    "The provided operation data is too long" : "Die bereitgestellten Betriebsdaten sind zu lang",
    "Invalid check provided" : "Ungültiger Test bereitgestellt",
    "Check %s does not exist" : "Die Prüfung %s existiert nicht",
    "Check %s is invalid" : "Die Prüfung %s ist ungültig",
    "Check %s is not allowed with this entity" : "Die Prüfung %s ist mit dieser Entität unzulässig",
    "The provided check value is too long" : "Der bereitgestellte Prüfwert ist zu lang",
    "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
    "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
    "Flow" : "Ablauf",
    "Nextcloud workflow engine" : "Nextcloud Arbeitsablauf-Engine",
    "Select a filter" : "Filter wählen",
    "Select a comparator" : "Wählen Sie einen Komparator",
    "Remove filter" : "Filter entfernen",
    "Audio" : "Audio",
    "Folder" : "Ordner",
    "Images" : "Bilder",
    "Office documents" : "Office-Dokumente",
    "PDF documents" : "PDF-Dokumente",
    "Video" : "Video",
    "Custom MIME type" : "Benutzerdefinierter MIME Typ",
    "Custom mimetype" : "Benutzerdefinierter MIME-Typ",
    "Select a file type" : "Dateityp auswählen",
    "e.g. httpd/unix-directory" : "z.B. httpd/unix-directory",
    "Please enter a valid time span" : "Bitte einen gültigen Zeitraum angeben",
    "Files WebDAV" : "WebDAV für Dateien",
    "Custom URL" : "Benutzerdefinierte URL",
    "Select a request URL" : "Wählen Sie eine Anforderungs-URL aus",
    "Android client" : "Android-Client",
    "iOS client" : "iOS-Client",
    "Desktop client" : "Desktop-Client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook Addons",
    "Custom user agent" : "Benutzerdefinierter User-Agent",
    "Select a user agent" : "User-Agenten wählen",
    "Select groups" : "Gruppen auswählen",
    "Groups" : "Gruppen",
    "Type to search for group …" : "Tippen um nach einer Gruppe zu suchen …",
    "Select a trigger" : "Einen Auslöser auswählen",
    "At least one event must be selected" : "Mindestens ein Termin muss ausgewählt werden",
    "Add new flow" : "Neuen Ablauf hinzufügen",
    "The configuration is invalid" : "Die Konfiguration ist ungültig",
    "Active" : "Aktiv",
    "Save" : "Speichern",
    "When" : "Wenn",
    "and" : "und",
    "Add a new filter" : "Neuen Filter hinzufügen",
    "Cancel" : "Abbrechen",
    "Delete" : "Löschen",
    "Available flows" : "Verfügbare Abläufe",
    "For details on how to write your own flow, check out the development documentation." : "Informationen wie eigene Abläufe erstellt werden, finden Sie in der Entwickler-Dokumentation.",
    "No flows installed" : "Keine Abläufe installiert",
    "Ask your administrator to install new flows." : "Bitten Sie Ihre Administration, neue Abläufe zu installieren.",
    "More flows" : "Weitere Abläufe",
    "Browse the App Store" : "App-Store durchsuchen",
    "Show less" : "Weniger anzeigen",
    "Show more" : "Mehr anzeigen",
    "Configured flows" : "Konfigurierte Abläufe",
    "Your flows" : "Ihre Abläufe",
    "No flows configured" : "Keine Abläufe eingerichtet",
    "matches" : "entspricht",
    "does not match" : "entspricht nicht",
    "is" : "ist",
    "is not" : "ist nicht",
    "File name" : "Dateiname",
    "File MIME type" : "Datei MIME-Typ",
    "File size (upload)" : "Dateigröße (beim Hochladen)",
    "less" : "weniger",
    "less or equals" : "weniger oder gleich",
    "greater or equals" : "größer oder gleich",
    "greater" : "größer",
    "Request remote address" : "Entfernte Adresse der Anfrage",
    "matches IPv4" : "entspricht IPv4",
    "does not match IPv4" : "entspricht nicht IPv4",
    "matches IPv6" : "entspricht IPv6",
    "does not match IPv6" : "entspricht nicht IPv6",
    "File system tag" : "Kollaboratives Schlagwort an Datei",
    "is tagged with" : "ist getaggt mit",
    "is not tagged with" : "ist nicht getaggt mit",
    "Request URL" : "Anfrage-URL",
    "Request time" : "Anfrage-Zeitpunkt",
    "between" : "zwischen",
    "not between" : "nicht zwischen",
    "Request user agent" : "User-Agent anfragen",
    "Group membership" : "Gruppenmitgliedschaft",
    "is member of" : "Ist Mitglied von",
    "is not member of" : "Ist kein Mitglied von",
    "Type to search for group …" : "Tippen um nach einer Gruppe zu suchen …"
},
"nplurals=2; plural=(n != 1);");
